
library(rphast)

mod_file = system.file("extdata", "hg19.100way.phastCons.mod", package="linACC")
mod      = read.tm(mod_file)

##- what we looking at
#====================
NBITS    = 10
specs    = c("hg19","panTro4","gorGor3","ponAbe2","nomLeu3")
specs    = as.vector(rbind(specs,specs))
specs = paste(specs,c(".sel",".bgc"),sep="")
PCUT     = 0.01 #- stop traversing if all over sig-thresh

#- enumerate the models for five leaf branches
#=============================================
mod.vecs = int2bitVec(0:(2^NBITS-1),NBITS)
mod.strs = int2bitStr(0:(2^NBITS-1),NBITS)
mod.vecs = t(apply(mod.vecs,1,as.logical))

#- reorder by numbers of parameters
ord                = order(apply(mod.vecs,2,sum))
mod.vecs           = mod.vecs[,ord]
mod.strs           = mod.strs[ord]
rownames(mod.vecs) = specs
colnames(mod.vecs) = mod.strs

#- make the adjacency matrix (nested *with one extra par*)
#=========================================================
amat = getAdjacency(mod.vecs)

TM.null      = mod
TM.null.cons = TM.null ; TM.null.cons$tree =  rescale.tree(tree=TM.null$tree,scale=.1)
LEN          = 100
NSIM         = 100

simFu <- function(TM,TM.null,LEN){
#=================================

        ali   = simulate.msa(object=TM,nsim=LEN)
        ftd   = fitNested(ali,mod.vecs,TM.null,amat)
        class = classifyNested(ftd,mod.vecs,pcut=0.01)
        return(class)
}

scaleSpec <- function(spec,esubs,LEN,TM){
#========================================

	st        = summary.tree(TM$tree)
	hg.ind    = which(st$name == spec)
  	hg.bl     = st$tparent[hg.ind]
	sel.par   = esubs/(LEN*hg.bl)
	TM.scld   = add.ls.mod(TM,branch=spec,sel=sel.par)
	return(TM.scld)	
}	

runSim <- function(TM,TM.null,NSIM,LEN,esubs,spec){
#==================================================
	
	tmp = lapply(1:NSIM, function(x) simFu(scaleSpec(spec,esubs,LEN,TM),TM.null,LEN)) 
	return(unlist( lapply(tmp,"[[",1)  ))
}


simClassHg = runSim(TM.null.cons,TM.null,10,100,3,"hg19")




